summaryrefslogtreecommitdiffstats
path: root/qtjava/javalib/examples/progressbar/ProgressBar.java
diff options
context:
space:
mode:
Diffstat (limited to 'qtjava/javalib/examples/progressbar/ProgressBar.java')
-rw-r--r--qtjava/javalib/examples/progressbar/ProgressBar.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/qtjava/javalib/examples/progressbar/ProgressBar.java b/qtjava/javalib/examples/progressbar/ProgressBar.java
index 88b547eb..0d05040d 100644
--- a/qtjava/javalib/examples/progressbar/ProgressBar.java
+++ b/qtjava/javalib/examples/progressbar/ProgressBar.java
@@ -67,11 +67,11 @@ ProgressBar( TQWidget parent, String name )
toplayout.addMultiCellWidget( progress, 1, 1, 0, 1 );
// connect the clicked() SIGNALs of the pushbuttons to SLOTs
- connect( start, SIGNAL(" clicked()"), this, SLOT(" slotStart()") );
- connect( reset, SIGNAL(" clicked()"), this, SLOT(" slotReset()") );
+ connect( start, TQ_SIGNAL(" clicked()"), this, TQ_SLOT(" slotStart()") );
+ connect( reset, TQ_SIGNAL(" clicked()"), this, TQ_SLOT(" slotReset()") );
- // connect the timeout() SIGNAL of the progress-timer to a SLOT
- connect( timer, SIGNAL(" timeout()"), this, SLOT(" slotTimeout()") );
+ // connect the timeout() TQ_SIGNAL of the progress-timer to a TQ_SLOT
+ connect( timer, TQ_SIGNAL(" timeout()"), this, TQ_SLOT(" slotTimeout()") );
// Let's start with normal speed...
normal.setChecked( true );
@@ -83,9 +83,9 @@ ProgressBar( TQWidget parent, String name )
}
/*
- SLOT slotStart
+ TQ_SLOT slotStart
*
- This SLOT is called if the user clicks start/pause/continue
+ This slot is called if the user clicks start/pause/continue
button
*/
@@ -123,9 +123,9 @@ void slotStart()
}
/*
- SLOT slotReset
+ TQ_SLOT slotReset
*
- This SLOT is called when the user clicks the reset button
+ This slot is called when the user clicks the reset button
*/
void slotReset()
@@ -148,9 +148,9 @@ void slotReset()
}
/*
- SLOT slotTimeout
+ TQ_SLOT slotTimeout
*
- This SLOT is called each ms when the timer is
+ This slot is called each ms when the timer is
active (== progress is running)
*/